SMS Helper
==========
SMS tool that can help you properly count the length of an SMS, calculate the part and what encoding it is.


Installation
------------
pip install smshelper


Examples
--------


Original Idea
-------------
[danxexe/sms-counter](https://github.com/danxexe/sms-counter)
